summaryrefslogtreecommitdiffstats
path: root/kdat/VerifyDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/VerifyDlg.h')
-rw-r--r--kdat/VerifyDlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/VerifyDlg.h b/kdat/VerifyDlg.h
index bc11524..41df846 100644
--- a/kdat/VerifyDlg.h
+++ b/kdat/VerifyDlg.h
@@ -80,11 +80,11 @@ public:
* @param fileno The tape file number of the archive to verify/restore.
* @param ranges A list of tar block ranges to read.
* @param restore TRUE means restore, FALSE means verify.
* @param tqparent The tqparent widget for the dialog.
* @param name The name of this widget.
*/
VerifyDlg( const TQString & workingDir, int fileno, const RangeList& ranges,
- bool restore = FALSE, TQWidget* tqparent = 0, const char* name = 0 );
+ bool restore = FALSE, TQWidget* parent = 0, const char* name = 0 );
/**
* Destroy the verify/restore dialog.
@@ -80,11 +80,11 @@ public:
* @param ranges A list of tar block ranges to read.
* @param restore TRUE means restore, FALSE means verify.
- * @param tqparent The tqparent widget for the dialog.
+ * @param parent The parent widget for the dialog.
* @param name The name of this widget.
*/